#!/system/bin/bash

exec >> /data/logs/tools_log/gel_update_logs.txt 2>&1

echo "***********************************************************"
echo "*               Starting GEL Update                       *"
echo "***********************************************************"

##############################################################################
# Android 下位机 升级脚本, 必须 以 root 权限执行
# param1 表示升级包所在路径, 比如 U 盘. 然后解压、复制 和 安装 apk
# param2 表示是否删除之前版本, 实现降版本功能
#############################################################################
# Make sure only root can run our script
if [[ $EUID -ne 0 ]]; then
	echo "YOU must be as root" 1>&2
	exit 1
fi


#build_out=DS70000Update.GEL
####################################################################################
# Temp dir for upgrading
####################################################################################
UPDATE_SOURCE=/mnt/tmp
UPDATE_BAKUP=/mnt/bak
UPDATE_TARGET=/rigol/

####################################################################################
# update target dir
####################################################################################
UPDATE_FLAG=$UPDATE_SOURCE/upgrade.txt
UPDATE_DEFAULT=$UPDATE_SOURCE/default.txt

####################################################################################
# Upgradation Package from param1
####################################################################################
UPDATE_ARG1=$1

#**********************************************************************************
#Decrypt
#**********************************************************************************

#**********************************************************************************
#Check version 
#**********************************************************************************


####################################################################################
# APK needed install
####################################################################################
UPDATE_DSO=$UPDATE_SOURCE/app/Sparrow.apk
UPDATE_WEB=$UPDATE_SOURCE/app/Webcontrol.apk
UPDATE_LUN=$UPDATE_SOURCE/app/Launcher.apk
UPDATE_HLP=$UPDATE_SOURCE/app/help.apk
UPDATE_HLP_EN=$UPDATE_SOURCE/app/help_en.apk

####################################################################################
# Uninstall old version if needed
####################################################################################
if [[ $UPDATE_ARG1 -eq "1" ]]; then
	pm uninstall com.rigol.scope
	#need boot with default param 
	touch $UPDATE_DEFAULT
fi

####################################################################################
# Bakup important file
####################################################################################
cp $UPDATE_TARGET/*  $UPDATE_BAKUP/ -R

####################################################################################
#copy FPGA
####################################################################################
#rm -f $UPDATE_TARGET/FPGA/* 
cp $UPDATE_SOURCE/FPGA/*          $UPDATE_TARGET/FPGA/

####################################################################################
#copy DRIVER
####################################################################################
#rm -f $UPDATE_TARGET/driver/*
cp $UPDATE_SOURCE/driver/*        $UPDATE_TARGET/driver/

####################################################################################
#copy misc
####################################################################################
#rm -f $UPDATE_TARGET/tools/*
#rm -f $UPDATE_TARGET/shell/*
rm -f $UPDATE_TARGET/image/*     >/dev/null 2>&1

mkdir -p $UPDATE_TARGET/data/
if [ -d $UPDATE_SOURCE/data/ ]; then
    cp $UPDATE_SOURCE/data/*      $UPDATE_TARGET/data/ -R
fi

mkdir -p $UPDATE_TARGET/data/default/
cp $UPDATE_SOURCE/data/default/*       $UPDATE_TARGET/data/default/

#根据进程名关键字杀死该进程
kill -9 $(pidof pmapService)

cp $UPDATE_SOURCE/tools/*         $UPDATE_TARGET/tools/
cp $UPDATE_SOURCE/shell/*         $UPDATE_TARGET/shell/

# test only
#cp $UPDATE_SOURCE/default/Key.data       $UPDATE_TARGET/data/


mkdir -p $UPDATE_TARGET/resource/
cp $UPDATE_SOURCE/resource/*      $UPDATE_TARGET/resource/ -R

chmod 777 $UPDATE_TARGET -R
sync

####################################################################################
# update the logic fw
####################################################################################

fpga_download_addr=0x400000
fpga_fw=/rigol/FPGA/BOOT.bin

# echo /rigol/shell/reload_fpga.sh  ${fpga_fw}   ${fpga_download_addr}
# /rigol/shell/reload_fpga.sh  ${fpga_fw}   ${fpga_download_addr}

####################################################################################
# update the APPs
####################################################################################

$UPDATE_TARGET/tools/pmapService &

####################################################################################
# 1. erase the fpga flash 
# 2. download the fpga fw
####################################################################################
/rigol/tools/get_current_time

echo /rigol/tools/spi2erase  ${fpga_fw}  ${fpga_download_addr} 
/rigol/tools/spi2erase  ${fpga_fw}  ${fpga_download_addr} 

/rigol/tools/get_current_time

echo /rigol/tools/spi2flash  ${fpga_fw}  ${fpga_download_addr} 
/rigol/tools/spi2flash  ${fpga_fw}  ${fpga_download_addr} 

echo setprop persist.rigol.fpga.boot.addr ${fpga_download_addr}
setprop persist.rigol.fpga.boot.addr ${fpga_download_addr}

/rigol/tools/get_current_time

#pm dump com.rigol.scope | grep 'versionName'
####################################################################################
# Webcontrol APK install. You can not install by checking version
####################################################################################
if [ -f $UPDATE_WEB ]; then
	echo pm install -r $UPDATE_WEB
	pm install -r $UPDATE_WEB  >/dev/null 2>&1
fi

####################################################################################
# Launcher APK install. You can not install by checking version
####################################################################################
if [ -f $UPDATE_LUN ]; then
	echo pm install -r $UPDATE_LUN
	pm install -r $UPDATE_LUN  >/dev/null 2>&1
fi

if [ -f $UPDATE_HLP ]; then
	pm install -r $UPDATE_HLP  >/dev/null 2>&1
	
	pm install -r $UPDATE_HLP_EN  >/dev/null 2>&1	
fi

####################################################################################
# Set flag for auto rebooting system
####################################################################################
touch $UPDATE_FLAG
sync

####################################################################################
# Scope APK install. return if failed  You can install WITHOUT VERSION CHECKING
####################################################################################
if [ -f $UPDATE_DSO ]; then
	echo pm install -r $UPDATE_DSO
	pm install -r $UPDATE_DSO  >/dev/null 2>&1

	#check if success
	if [ $? -ne 0 ]; then
		#restore when install failed	
		cp $UPDATE_BAKUP/* $UPDATE_TARGET/ -R  
		echo 'Upgradation failed'
		rm $UPDATE_FLAG
		sync
		exit 2
	fi
fi

echo "OK"

echo ... Ending - GEL Update ...
echo

# exit 0

# reboot

# sleep 60

# ####################################################################################
# # 3. reload fpga fw for scope app
# ####################################################################################
# pushd /rigol/driver/ > /dev/null
    # kill -9 $(pidof com.rigol.scope)
    # sleep 1
    # rmmod xdma
    # rmmod pcie_rockchip

    # /rigol/tools/spi2boot ${fpga_download_addr}
    # setprop persist.rigol.fpga.boot.addr ${fpga_download_addr}

    # sleep 10
    # insmod pcie-rockchip.ko
    # insmod xdma.ko
    # sleep 1
    # chmod 777 /dev/xdma*
# popd  > /dev/null

### test
# /rigol/shell/do_update.sh /data/logs/DHO800_DHO900_Update.GEL
# /rigol/shell/do_update.sh /data/logs/DHO800_DHO900_Update.GEL  1

