#!/system/bin/bash

os_version=$(getprop ro.rigol.system.version | sed "s@\.@@g" | sed 's/^0*//')
exec >> /data/logs/tools_log/boot_up.txt 2>&1
echo "OS version is : ${os_version}"

fpga_boot_addr=$(getprop persist.rigol.fpga.boot.addr)
if [[ x"${fpga_boot_addr}" == x"" ]]; then
    fpga_boot_addr=0x000000
fi

boot_record=$(getprop persist.rigol.boot.record)
if [[ x"${boot_record}" == x"" ]]; then
    boot_record=0
else
    boot_record=$( expr ${boot_record} + 1 )
fi

setprop persist.rigol.boot.record ${boot_record}

suffix_num=$( expr ${boot_record} % 10 )

echo "***********************************************************"
echo "*               Starting RIGOL App                        * @ ${boot_record}"
echo "***********************************************************"

[ ! -d /data/logs/tools_log/ ] && mkdir -p /data/logs/tools_log/ && chmod 777 /data/logs/tools_log/ 

echo  
echo ... Starting - start_rigol_app.sh ... 

/rigol/tools/get_current_time

### insmod ethernet PHY driver for Motorcomm - YT8512
ifconfig eth0 down
insmod /rigol/driver/motorcomm.ko
ifconfig eth0 up

# Get the Hardware version
insmod /rigol/driver/hdcode_gpio.ko
chmod 777 /dev/hdcode_gpio

# 配置 FPGA 程序
# /rigol/tools/get_current_time
# echo "/rigol/tools/spi2fpga"
# /rigol/tools/spi2fpga

# /rigol/tools/get_current_time


# 配置 LMK04821 PLL Clock - 使用 GPIO 模拟 SPI : /dev/spi_3wires
#insmod /rigol/driver/spi2pll_gpio.ko
#/rigol/tools/spi2pll

# 配置 LMX2582 PLL Clock - 使用 GPIO 模拟 SPI : /dev/spi_3wires_lxm2582
insmod /rigol/driver/spi2pll_lxm2582_gpio.ko
/rigol/tools/spi2pll_lxm2582

insmod /rigol/driver/afg_gpio.ko
chmod 777 /dev/afg_gpio

# 配置 ADF4360 PLL Clock - 使用标准 SPI
# /rigol/tools/sspi2pll

# 加载 PCIE & XDMA 驱动
/rigol/tools/get_current_time
echo /rigol/tools/spi2boot ${fpga_boot_addr}
/rigol/tools/spi2boot ${fpga_boot_addr}
sleep 10
/rigol/shell/load_pcie.sh
/rigol/tools/get_current_time

# 加载 GPIO 模拟 SPI 驱动 ：AFE config  :  /dev/spi_simulate
insmod /rigol/driver/spi2afe_gpio.ko
chmod 777 /dev/spi*
# ls -l /dev/spi*

# 再次设置 chmod 777 /dev/spi* , 确保 chmod 配置成功
read -t 0.1
chmod 777 /dev/spi*
ls -l /dev/spi*

# 加载 MIPI 触摸屏驱动 - MIPI_JD9365 ilitek (workaround: need to insmod ilitek_ts.ko at first, then insmod focaltech_ts.ko)
# insmod /rigol/driver/ilitek_ts.ko

# 加载 MIPI 触摸屏驱动 - focaltech for gaozhan
# insmod /rigol/driver/focaltech_ts_gaozhan.ko

# 加载 beeper 驱动
insmod /rigol/driver/beeper_gpio.ko
chmod 777 /dev/pwm-1

# fg_m2c_gpio_ko
insmod /rigol/driver/fg_m2c_gpio.ko
chmod 777 /dev/fg_m2c_gpio

# 加载 PWM Fan 驱动
# insmod /rigol/driver/pwm_fan.ko
# chmod 777 /dev/pwm_fan

# 把 存放校准数据的目录 访问权限打开
chmod 777 /rigol/data/*

mkdir -p  /rigol/data/probe
chmod 777 /rigol/data/probe

# 在 /mnt/ 下 创建 临时目录 用于更新版本
mkdir -p /mnt/tmp
chmod 777 /mnt/tmp


# 创建用户区目录，为了 和 系统应用数据 隔离
mkdir -p /data/UserData
#ln -s /data/UserData userdata
chmod 777 /data/UserData
chmod 777 /dev/vendor_storage

# 加载 DAC 驱动 : /dev/dac_gear_change
insmod /rigol/driver/dac_gpio.ko
chmod 777 /dev/dac_gear_change

# 检测 LA 探头是否插入，gpio120 引脚对应 GPIO3_D0
chmod 777 /sys/class/gpio/export
echo 120 > /sys/class/gpio/export
chmod 777 /sys/class/gpio/gpio120/direction
chmod 777 /sys/class/gpio/gpio120/value

# 加载 AFE RMS 驱动 : /dev/afe_rms
# insmod /rigol/driver/afe_rms_gpio.ko
# chmod 777 /dev/afe_rms

# FTP 服务器，用于通过 ftp 协议 读取文件，默认开放给客户
tcpsvd 0:21 ftpd ftpd -w /data/UserData/ &

# disable Auto time
# settings put global auto_time 0
# 更新系统时间和日期 : Set system time from hardware clock
hwclock -s -f /dev/rtc0 &

/rigol/tools/pmapService &

#stop adbd &

setprop persist.sys.timezone Asia/Shanghai

echo 255 > /sys/devices/platform/backlight/backlight/backlight/brightness

### Start Main APP
# sleep 3
# am start -n com.rigol.scope/.MainActivity

echo
getprop | grep -i rigol
echo

/rigol/tools/get_current_time

# 加载 MIPI 触摸屏驱动 - focaltech for guoxian
sleep 20
insmod /rigol/driver/focaltech_ts.ko

echo ... Ending - start_rigol_app.sh ...
echo 

### Just for debug : save the boot logs
# /system/bin/logcat -b all > /data/logs/tools_log/$(date "+%Y.%m.%d_%H.%M.%S") &
rm -f /data/logs/tools_log/dmesg_${suffix_num}.txt*
rm -f /data/logs/tools_log/logcat_${suffix_num}.txt*
echo ========================== boot record : ${boot_record} ========================= >> /data/logs/tools_log/dmesg_${suffix_num}.txt
echo ========================== boot record : ${boot_record} ========================= >> /data/logs/tools_log/logcat_${suffix_num}.txt
/system/bin/logcat -b kernel -f /data/logs/tools_log/dmesg_${suffix_num}.txt -r 1024 -n 2 &
/system/bin/logcat -b all -f /data/logs/tools_log/logcat_${suffix_num}.txt -r 1024 -n 4 &

project_name=sparrow
sleep 20
[ -f /mnt/media_rw/*/fetch_${project_name}_logs.txt ] && /rigol/shell/copy_logs_to_udisk.sh || echo "does not exist fetch_${project_name}_logs.txt"
[ -f /mnt/media_rw/*/force_update_${project_name}.txt ] && /rigol/shell/force_update_gel.sh || echo "does not exist force_update_${project_name}.txt"
[ -f /mnt/media_rw/*/force_enter_bootloader_${project_name}.txt ] && reboot bootloader || echo "does not exist force_enter_bootloader_${project_name}.txt"
# /rigol/tools/reboot_system

